pub struct SurfaceRoot { /* private fields */ }Implementations
Sourceimpl SurfaceRoot
impl SurfaceRoot
pub fn new(content: Box<dyn LayoutItem>) -> Result<Self, LayoutError>
pub fn animate_in(self) -> Self
Sourcepub fn animate(self, transition: SurfaceTransition) -> Self
pub fn animate(self, transition: SurfaceTransition) -> Self
Drives the root from a transition the caller owns, so it can also send the surface back out — see
SurfaceTransition::leave.